@@ -32,5 +32,8 @@ static unsigned long long get_used_blocks();
 /// readbitmap - cread and heck bitmap, reference dumpe2fs
 extern void readbitmap(char* device, image_head image_hdr, char* bitmap);
 
+/// get extfs type
+static int test_extfs_type(char* device);
+
 /// read super block and write to image head
 extern void initial_image_hdr(char* device, image_head* image_hdr);
