@@ -39,6 +39,7 @@
 /// global variable
 cmd_opt		opt;			/// cmd_opt structure defined in partclone.h
 p_dialog_mesg	m_dialog;			/// dialog format string
+char *EXECNAME="partclone.restore";
 
 /**
  * main functiom - for colne or restore data
@@ -411,7 +412,7 @@ int main(int argc, char **argv){
     free(bitmap);   /// free bitmp
     if(opt.ncurses)
 	close_ncurses();
-    printf("clone successfully\n");
+    printf("Successfully cloned.\n");
     if(opt.debug)
 	close_log();
     return 0;	    /// finish
